@@ -1,6 +1,6 @@
 /*
  * chatviewcommon.h - shared part of any chatview
- * Copyright (C) 2010 Rion
+ * Copyright (C) 2010  Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  */
 
@@ -30,23 +30,29 @@ class QWidget;
 class ChatViewCommon
 {
 public:
-	ChatViewCommon() : _nickNumber(0) { }
-	void setLooks(QWidget *);
-	inline const QDateTime& lastMsgTime() const { return _lastMsgTime; }
-	bool updateLastMsgTime(QDateTime t);
-	QString getMucNickColor(const QString &, bool,
-							QStringList validList = QStringList());
-	QList<QColor> getPalette();
+    enum UserType {
+        LocalParty,
+        RemoteParty,
+        Participant
+    };
+
+
+    ChatViewCommon() : _nickNumber(0) { }
+    void setLooks(QWidget *);
+    inline const QDateTime& lastMsgTime() const { return _lastMsgTime; }
+    bool updateLastMsgTime(QDateTime t);
+    QString getMucNickColor(const QString &, bool,
+                            QStringList validList = QStringList());
+    QList<QColor> getPalette();
 
 protected:
-	QDateTime _lastMsgTime;
+    QDateTime _lastMsgTime;
 
 private:
-	void generatePalette();
-	bool compatibleColors(const QColor &, const QColor &);
-	int _nickNumber;
-	QMap<QString,int> _nicks;
-	QList<QColor> _palette;
+    QList<QColor> &generatePalette();
+    bool compatibleColors(const QColor &, const QColor &);
+    int _nickNumber;
+    QMap<QString,int> _nicks;
 };
 
 #endif
