@@ -1,6 +1,6 @@
 /*
  * boarddelegate.h - plugin
- * Copyright (C) 2010  Khryukin Evgeny
+ * Copyright (C) 2010  Evgeny Khryukin
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
 #define BOARDDELEGATE_H
 
 #include <QItemDelegate>
+namespace Chess {
 
 class BoardDelegate : public QItemDelegate
 {
@@ -32,4 +33,5 @@ public:
 	virtual void paint ( QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index ) const;
 
 };
+}
 #endif // BOARDDELEGATE_H
