@@ -45,7 +45,7 @@
 #define constNew "newsymbol"
 #define constShortCut "shortcut"
 #define constNotTranslate "nottranslate"
-#define constVersion "0.4.5"
+#define constVersion "0.4.6"
 
 static const QString mucData = "groupchat";
 static const QString chatData = "chat";
@@ -88,6 +88,8 @@ public:
 	//Tabs
 	virtual void setupChatTab(QWidget* tab, int account, const QString& contact);
 	virtual void setupGCTab(QWidget* tab, int account, const QString& contact);
+	virtual bool appendingChatMessage(int account, const QString& contact,
+					  QString& body, QDomElement& html, bool local);
 
 	virtual QString pluginInfo();
 	virtual QPixmap icon() const;
@@ -109,7 +111,7 @@ private:
 	bool enabled_;
 	bool notTranslate;
 	QMap<QString,QString> map;
-	QMap<QString,QString> mapBakup;
+	QMap<QString,QString> mapBackup;
 	QTableWidget * table;
 	QLineEdit *shortCutWidget;
 	OptionAccessingHost* psiOptions;
@@ -212,7 +214,7 @@ TranslatePlugin::TranslatePlugin()
 	map.insert("/",QString::fromUtf8(".")); map.insert(QString::fromUtf8("."),"/");
 	map.insert(".",QString::fromUtf8("ю")); map.insert(QString::fromUtf8("ю"),".");
 
-	mapBakup = map;
+	mapBackup = map;
 }
 
 QString TranslatePlugin::name() const
@@ -539,10 +541,10 @@ void TranslatePlugin::restoreMap()
 	disconnect(table,SIGNAL(cellChanged(int,int)),this,SLOT(changeItem(int,int)));
 	table->clear();
 	table->setRowCount(0);
-	foreach(const QString& symbol, mapBakup.keys()){
+	foreach(const QString& symbol, mapBackup.keys()){
 		table->insertRow(table->rowCount());
 		table->setItem(table->rowCount()-1,0,new QTableWidgetItem(symbol));
-		table->setItem(table->rowCount()-1,1,new QTableWidgetItem(mapBakup.value(symbol)));
+		table->setItem(table->rowCount()-1,1,new QTableWidgetItem(mapBackup.value(symbol)));
 	}
 	connect(table,SIGNAL(cellChanged(int,int)),this,SLOT(changeItem(int,int)));
 	hack();
@@ -581,6 +583,12 @@ void TranslatePlugin::setupGCTab(QWidget* tab, int /*account*/, const QString& /
 	setupTab(tab, mucData);
 }
 
+bool TranslatePlugin::appendingChatMessage(int/* account*/, const QString &/*contact*/,
+					   QString &/*body*/, QDomElement &/*html*/, bool /*local*/)
+{
+	return false;
+}
+
 void TranslatePlugin::actionDestroyed(QObject *obj)
 {
 	QAction* act = static_cast<QAction*>(obj);
