@@ -1,6 +1,6 @@
 /*
  * videostatusplugin.cpp - plugin
- * Copyright (C) 2010  KukuRuzo, Khryukin Evgeny
+ * Copyright (C) 2010  KukuRuzo, Evgeny Khryukin
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,9 +28,9 @@
 
 #include "ui_options.h"
 
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
 #include "windows.h"
-#elif defined (Q_WS_X11)
+#elif defined (HAVE_DBUS)
 #include <QCheckBox>
 #include <QDBusMessage>
 #include <QDBusConnection>
@@ -56,7 +56,8 @@ static const QList<StringMap> players = QList<StringMap>() << StringMap("vlc", "
 							   << StringMap("Totem", "Totem (>=2.30.2)")
 							   << StringMap("kaffeine", "Kaffeine (>=1.0)")
 							   << StringMap("mplayer", "GNOME MPlayer")
-							   << StringMap("dragonplayer", "Dragon Player");
+							   << StringMap("dragonplayer", "Dragon Player")
+							   << StringMap("smplayer", "SMPlayer");
 struct PlayerStatus
 {
 	int playStatus;
@@ -90,7 +91,7 @@ static const QDBusArgument & operator>>(const QDBusArgument &arg, PlayerStatus &
 }
 #endif
 
-#define constVersion "0.2.5"
+#define constVersion "0.2.8"
 
 #define constStatus "status"
 #define constStatusMessage "statusmessage"
@@ -133,7 +134,7 @@ private:
 	PsiAccountControllingHost* accControl;
 	QString status, statusMessage;
 	Ui::OptionsWidget ui_;
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	bool playerGMPlayer_; //только для не MPRIS плеера GMPlayer
 	QHash<QString, bool> playerDictList;
 	QPointer<QTimer> checkTimer; //Таймер Gnome Mplayer
@@ -156,18 +157,14 @@ private:
 		QString message;
 	};
 	QHash<int, StatusString> statuses_;
-#ifdef Q_WS_WIN
-	void getDesktopSize();
+#ifdef Q_OS_WIN
 	bool isFullscreenWindow();
-
-	int desktopWidth;
-	int desktopHeight;
 #endif
 	void setPsiGlobalStatus(const bool set);
 	void setStatusTimer(const int delay, const bool isStart);
 
 private slots:
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	void checkMprisService(const QString &name, const QString &oldOwner, const QString &newOwner);
 	void onPlayerStatusChange(const PlayerStatus &ps);
 	void onPropertyChange(const QDBusMessage &msg);
@@ -187,7 +184,7 @@ Q_EXPORT_PLUGIN(VideoStatusChanger);
 VideoStatusChanger::VideoStatusChanger()
 {
 	enabled = false;
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	playerGMPlayer_ = false;
 	foreach (StringMap item, players) {
 		playerDictList.insert(item.first, false);
@@ -239,7 +236,7 @@ bool VideoStatusChanger::enable()
 {
 	if(psiOptions) {
 		enabled = true;
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 		qDBusRegisterMetaType<PlayerStatus>();
 		services_ = QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
 		//проверка на наличие уже запущенных плееров
@@ -263,7 +260,7 @@ bool VideoStatusChanger::enable()
 		restoreDelay = psiOptions->getPluginOption(constRestoreDelay, QVariant(restoreDelay)).toInt();
 		setDelay = psiOptions->getPluginOption(constSetDelay, QVariant(setDelay)).toInt();
 		fullScreen = psiOptions->getPluginOption(constFullScreen, fullScreen).toBool();
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 		//цепляем сигнал появления новых плееров
 		QDBusConnection::sessionBus().connect(QLatin1String("org.freedesktop.DBus"),
 						      QLatin1String("/org/freedesktop/DBus"),
@@ -284,7 +281,7 @@ bool VideoStatusChanger::disable()
 {
 	enabled = false;
 	fullST.stop();
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	//отключаем прослушку активных плееров
 	foreach(const QString& player, services_) {
 		disconnectFromBus(player);
@@ -308,7 +305,7 @@ bool VideoStatusChanger::disable()
 
 void VideoStatusChanger::applyOptions()
 {
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	//читаем состояние плееров
 	if (playerDictList.size() > 0) {
 		foreach (const QString& item, playerDictList.keys()) {
@@ -348,7 +345,7 @@ void VideoStatusChanger::applyOptions()
 
 void VideoStatusChanger::restoreOptions()
 {
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	//читаем состояние плееров
 	if (playerDictList.size() > 0) {
 		foreach (const QString& item, playerDictList.keys()) {
@@ -359,7 +356,7 @@ void VideoStatusChanger::restoreOptions()
 			}
 		}
 	}
-#elif defined (Q_WS_WIN)
+#elif defined (Q_OS_WIN)
 	ui_.groupBox->hide();
 #endif
 	QStringList list;
@@ -380,7 +377,7 @@ QWidget* VideoStatusChanger::options()
 	}
 	QWidget *optionsWid = new QWidget();
 	ui_.setupUi(optionsWid);
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	//добавляем чекбоксы плееров
 	int i = 0;
 	int columns = (players.length() < 5) ? 2 : 3;
@@ -418,7 +415,7 @@ QPixmap VideoStatusChanger::icon() const
 	return QPixmap(":/icons/videostatus.png");
 }
 
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 bool VideoStatusChanger::isPlayerValid(const QString &service) //проверка является ли плеер разрешенным
 {
 	foreach (const QString& item, playerDictList.keys()) {
@@ -623,7 +620,7 @@ void VideoStatusChanger::asyncCallFinished(QDBusPendingCallWatcher *watcher)
 
 void VideoStatusChanger::fullSTTimeout()
 {
-#ifdef Q_WS_X11
+#ifdef HAVE_DBUS
 	Window w = activeWindow();
 	Display  *display = X11Info::display();
 	bool full = false;
@@ -649,7 +646,7 @@ void VideoStatusChanger::fullSTTimeout()
 	}
 	if(data)
 		XFree(data);
-#elif defined (Q_WS_WIN)
+#elif defined (Q_OS_WIN)
 	bool full = isFullscreenWindow();
 #endif
 	if(full) {
@@ -662,52 +659,20 @@ void VideoStatusChanger::fullSTTimeout()
 	}
 }
 
-#ifdef Q_WS_WIN
-
-void VideoStatusChanger::getDesktopSize()
-{
-	RECT dSize;
-	if (GetWindowRect(GetDesktopWindow(), &dSize)) {
-		desktopWidth = abs(dSize.right - dSize.left);
-		desktopHeight = abs(dSize.bottom - dSize.top);
-	}
-	else{
-		desktopWidth = GetSystemMetrics(SM_CXSCREEN);
-		desktopHeight = GetSystemMetrics(SM_CYSCREEN);
-	}
-}
-
+#ifdef Q_OS_WIN
 bool VideoStatusChanger::isFullscreenWindow()
 {
-	HWND topWindow = GetForegroundWindow();
-	if (topWindow != NULL) {
-		//check for Progman window by GetWindow method
-		bool isDesktop = (GetWindow(GetWindow(GetDesktopWindow(), GW_CHILD), GW_HWNDLAST) == topWindow);
-		if (!isDesktop) {
-			//check for Progman and WorkerW by the name of the windows class
-			QByteArray ba(4 * sizeof(wchar_t), 0);
-			if (GetClassNameW(topWindow, (wchar_t*)ba.data(), ba.size()) > 0) {
-				QString className = QString::fromWCharArray((wchar_t*)ba.data(), ba.size());
-				if (className.contains("Progman", Qt::CaseInsensitive)
-				    || className.contains("WorkerW", Qt::CaseInsensitive)) {
-					isDesktop = true;
-				}
-			}
-		}
-		getDesktopSize();
-		WINDOWINFO info;
-		memset(&info, 0, sizeof(WINDOWINFO));
-		if (GetWindowInfo(topWindow, &info)) {
-			int x = info.rcWindow.left;
-			int y = info.rcWindow.top;
-			int wWidth = info.rcClient.right;
-			int wHeight = info.rcClient.bottom;
-			if (x == 0
-			    && y == 0
-			    && wWidth >= desktopWidth
-			    && wHeight >= desktopHeight
-			    && !isDesktop) {
-				return true;
+	HWND hWnd = GetForegroundWindow();
+	RECT appBounds;
+	RECT rc;
+	if (GetWindowRect(GetDesktopWindow(), &rc)) {
+		if(hWnd != GetDesktopWindow() && hWnd != GetShellWindow())
+		{
+			if (GetWindowRect(hWnd, &appBounds)) {
+				return (appBounds.bottom == rc.bottom
+					&& appBounds.left == rc.left
+					&& appBounds.right == rc.right
+					&& appBounds.top == rc.top);
 			}
 		}
 	}
