@@ -24,34 +24,46 @@
 #include <QObject>
 #include <QString>
 
+#include "xmpp_caps.h"
+
 namespace XMPP {
-	class Client;
+    class Client;
+    class Features;
+    class Jid;
+    class DiscoItem;
 }
 
+using namespace XMPP;
+
 class ServerInfoManager : public QObject
 {
-	Q_OBJECT
+    Q_OBJECT
 
 public:
-	ServerInfoManager(XMPP::Client* client);
+    ServerInfoManager(XMPP::Client* client);
 
-	const QString& multicastService() const;
-	bool hasPEP() const;
+    const QString& multicastService() const;
+    bool hasPEP() const;
+    inline const Features &features() const { return features_; }
+    bool canMessageCarbons() const;
 
 signals:
-	void featuresChanged();
+    void featuresChanged();
 
 private slots:
-	void disco_finished();
-	void initialize();
-	void deinitialize();
-	void reset();
+    void disco_finished();
+    void initialize();
+    void deinitialize();
+    void reset();
 
 private:
-	XMPP::Client* client_;
-	QString multicastService_;
-	bool featuresRequested_;
-	bool hasPEP_;
+    XMPP::Client* client_;
+    CapsSpec caps_;
+    Features features_;
+    QString multicastService_;
+    bool featuresRequested_;
+    bool hasPEP_;
+    bool _canMessageCarbons;
 };
 
 #endif
